### Name: contour3d
### Title: Draw an Isosurface, a Three Dimension Contour Plot
### Aliases: contour3d
### Keywords: hplot

### ** Examples

  #Example 1: Draw a ball
  f <- function(x, y, z)x^2+y^2+z^2
  x <- seq(-2,2,len=20)
  contour3d(f,4,x,x,x)

  #Example 2: Nested contours of mixture of three tri-variate normal densities
  nmix3 <- function(x, y, z, m, s) {
      0.4 * dnorm(x, m, s) * dnorm(y, m, s) * dnorm(z, m, s) +
      0.3 * dnorm(x, -m, s) * dnorm(y, -m, s) * dnorm(z, -m, s) +
      0.3 * dnorm(x, m, s) * dnorm(y, -1.5 * m, s) * dnorm(z, m, s)
  }
  f <- function(x,y,z) nmix3(x,y,z,.5,.5)
  g <- function(n = 40, k = 5, alo = 0.1, ahi = 0.5, cmap = heat.colors) {
      th <- seq(0.05, 0.2, len = k)
      col <- rev(cmap(length(th)))
      al <- seq(alo, ahi, len = length(th))
      x <- seq(-2, 2, len=n)
      for (i in seq(along = th)) {
           contour3d(f,th[i],x,x,x,color=col[i],alpha=al[i],
                     add = (i != 1))
      }
      rgl.bg(col="white")
  }
  g(40,5)

## Not run: 
##D   #Example 3: Nested contours for FMRI data.
##D   library(AnalyzeFMRI)
##D   a<-f.read.analyze.volume(system.file("example.img", package="AnalyzeFMRI"))
##D   contour3d(aperm(a[,,,1],c(1,3,2)),1:64,1.5*(1:21),1:64,lev=3000,alpha=0.5)
##D   contour3d(aperm(a[,,,1],c(1,3,2)),1:64,1.5*(1:21),1:64,lev=8000,
##D             col="red",add=TRUE, alpha=0.5)
##D   contour3d(aperm(a[,,,1],c(1,3,2)),1:64,1.5*(1:21),1:64,lev=10000,
##D             col="green",add=TRUE)
##D   
## End(Not run)



